# NoobStuffs

[![PyPi version](https://img.shields.io/pypi/v/noobstuffs)](https://pypi.org/project/noobstuffs/)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/e73fc5d0a6b64bb8a6c286f88c1dc590)](https://www.codacy.com/gh/PrajjuS/NoobStuffs/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=PrajjuS/NoobStuffs&amp;utm_campaign=Badge_Grade)

>Python3 library which consists of codes that are frequently used for my personal projects

## Installation

```
pip install noobstuffs
```

## Credits

Inspired by [sebaubuntu_libs](https://github.com/SebaUbuntu/sebaubuntu_libs)
